@@ -25,7 +25,9 @@ from django.http import (HttpRequest, HttpResponse, HttpResponseBadRequest,
                          HttpResponseRedirect, HttpResponseServerError)
 from django.shortcuts import render
 from django.template import TemplateDoesNotExist
+from django.urls import reverse
 from django.utils.decorators import method_decorator
+from django.utils.http import urlquote
 from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import View
 from django.utils.module_loading import import_string
@@ -166,7 +168,7 @@ class LoginView(SPConfigMixin, View):
                               "Discovery Service: {}").format(discovery_service))
                 login_url = request.build_absolute_uri(reverse('saml2_login'))
                 login_url = '{0}?next={1}'.format(login_url,
-                                                  urlquote(came_from, safe=''))
+                                                  urlquote(next_path, safe=''))
                 ds_url = '{0}?entityID={1}&return={2}&returnIDParam=idp'
                 ds_url = ds_url.format(discovery_service,
                                        urlquote(
@@ -390,7 +392,7 @@ class AssertionConsumerServiceView(SPConfigMixin, View):
         try:
             self.custom_validation(response)
         except Exception as e:
-            logger.warning("SAML Response validation error: {e}")
+            logger.warning(f"SAML Response validation error: {e}")
             return self.handle_acs_failure(request, status=400, exception=SuspiciousOperation('SAML2 validation error'))
 
         session_id = response.session_id()
